﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonColorPicker.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;
using System.IO;
using System.Web.UI;

/// <summary>
/// Ribbon color picker
/// </summary>
public partial class RibbonColorPicker : RibbonControl
{
	#region Fields

	/// <summary>
	/// Javascript function to call on client click
	/// </summary>
	private string clientClick = string.Empty;

	/// <summary>
	/// Do we show the default color
	/// </summary>
	private bool showDefaultColor = true;

	/// <summary>
	/// Do we show the default palette
	/// </summary>
	private bool showDefaultPalette = true;

	#endregion Fields

	#region Ctor

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonColorPicker"/> class.
	/// </summary>
	public RibbonColorPicker()
	{
	}
	#endregion Ctor

	#region Properties

	/// <summary>
	/// Gets or sets the on client click.
	/// </summary>
	/// <value>The on client click.</value>
	public string OnClientClick
	{
		get
		{
			return this.clientClick;
		}

		set
		{
			this.CheckDisposed();
			this.clientClick = value;
		}
	}

	/// <summary>
	/// Gets or sets a value indicating whether the ColorPicker shows the default Color Item on top of the control
	/// </summary>
	/// <value><c>true</c> if [show default color]; otherwise, <c>false</c>.</value>
	public bool ShowDefaultColor
	{
		get
		{
			return this.showDefaultColor;
		}

		set
		{
			this.CheckDisposed();
			this.showDefaultColor = value;
		}
	}

	/// <summary>
	/// Gets or sets a value indicating whether the ColorPicker shows the Default palette at the bottom of the control
	/// </summary>
	/// <value><c>true</c> if [show default palette]; otherwise, <c>false</c>.</value>
	public bool ShowDefaultPalette
	{
		get
		{
			return this.showDefaultPalette;
		}

		set
		{
			this.CheckDisposed();
			this.showDefaultPalette = value;
		}
	}

	#endregion Properties

	#region Methods

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
		this.PlaceHolder_DefaultColor.Visible = this.showDefaultColor;
		this.PlaceHolder_DefaultPalette.Visible = this.showDefaultPalette;
	}

	/// <summary>
	/// Override the Render Method to use the good Javascript Function
	/// </summary>
	/// <param name="writer">Objet <see cref="T:System.Web.UI.HtmlTextWriter"/> qui reçoit le contenu du contrôle serveur.</param>
	protected override void Render(HtmlTextWriter writer)
	{
		this.CheckDisposed();
		MemoryStream streamOur = null;
		StreamWriter writerOur = null;
		try
		{
			streamOur = new System.IO.MemoryStream();
			writerOur = new System.IO.StreamWriter(streamOur);
			using (HtmlTextWriter ourWriter = new HtmlTextWriter(writerOur))
			{
				base.Render(ourWriter);
				ourWriter.Flush();
				streamOur.Position = 0;
				using (System.IO.StreamReader reader = new System.IO.StreamReader(streamOur))
				{
					string text = reader.ReadToEnd();
					text = text.Replace("{ClientClick}", this.clientClick);
					Response.Write(text);
					//// reader.Close();
				}
			}
		}
		finally
		{
			if (streamOur != null)
			{
				streamOur.Dispose();
			}

			if (writerOur != null)
			{
				writerOur.Dispose();
			}
		}
	}

	#endregion Methods
}