﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonControl.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>François Le Rolland</author>
//-----------------------------------------------------------------------------
using System;
using System.Web.UI;

/// <summary>
/// Ribbon control
/// </summary>
public partial class RibbonControl : UserControl
{
	/// <summary>
	/// True if the control is disposed
	/// </summary>
	private bool disposed;

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonControl"/> class.
	/// </summary>
	public RibbonControl() : base()
	{
		this.Disposed += new EventHandler(this.RibbonControl_Disposed);
	}

	/// <summary>
	/// Checks if this instance is disposed.
	/// </summary>
	protected void CheckDisposed()
	{
		if (this.disposed)
		{
			throw new ObjectDisposedException(this.GetType().Name);
		}
	}

	/// <summary>
	/// Handles the Disposed event of the ribbonControl control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	private void RibbonControl_Disposed(object sender, EventArgs e)
	{
		this.disposed = true;
	}
}
