﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonDDIconItem.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;
using System.Web.UI;

/// <summary>
/// Ribbon drop down icon item
/// </summary>
public partial class RibbonDDIconItem : RibbonCollectionControl
{
	#region Ctor

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonDDIconItem"/> class.
	/// </summary>
	public RibbonDDIconItem()
	{
	}
	#endregion Ctor

	#region Properties
	/// <summary>
	/// Gets or sets the image URL.
	/// </summary>
	/// <value>The image URL.</value>
	public string ImageUrl
	{
		get;
		set;
	}

	/// <summary>
	/// Gets or sets the tooltip.
	/// </summary>
	/// <value>The tooltip.</value>
	public string Tooltip
	{
		get;
		set;
	}
	#endregion Properties

	#region Protected override methods

	/// <summary>
	/// Raises the <see cref="E:System.Web.UI.Control.PreRender"/> event.
	/// </summary>
	/// <param name="e">An <see cref="T:System.EventArgs"/> object that contains the event data.</param>
	protected override void OnPreRender(EventArgs e)
	{
		base.OnPreRender(e);

		foreach (var item in this.Items)
		{
			this.PlaceHolder_menu.Controls.Add(item);
		}

		this.div_item.Attributes["title"] = this.Tooltip;
		this.Image1.ImageUrl = this.ImageUrl;
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
		this.div_item.Attributes.Add("onclick", "SBRibbon.ShowMenu(this, '" + this.div_menu.ClientID + "')");
		this.div_item.Attributes.Add("onmouseout", "SBRibbon.HideMenu('" + this.div_menu.ClientID + "')");
		this.div_menu.Attributes.Add("onmouseover", "SBRibbon.HideMenu('" + this.div_menu.ClientID + "')");
	}
	#endregion Protected override methods
}