﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonDualGroup.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;
using System.Collections.ObjectModel;
using System.Web.UI;

/// <summary>
/// Ribbon dual group
/// </summary>
public partial class RibbonDualGroup : RibbonControl
{
	#region Fields

	/// <summary>
	/// Items in the left column
	/// </summary>
	private Collection<Control> leftItems;

	/// <summary>
	/// Items in the right column
	/// </summary>
	private Collection<Control> rightItems;

	#endregion Fields

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonDualGroup"/> class.
	/// </summary>
	public RibbonDualGroup()
	{
		this.leftItems = new Collection<Control>();
		this.rightItems = new Collection<Control>();
	}

	#region Properties

	/// <summary>
	/// Gets or sets the group align.
	/// </summary>
	/// <value>The group align.</value>
	public GrpAlign GroupAlign { get; set; }

	/// <summary>
	/// Gets the left content template.
	/// </summary>
	/// <value>The left content template.</value>
	[PersistenceMode(PersistenceMode.InnerProperty)]
	public Collection<Control> LeftContentTemplate
	{
		get { return this.leftItems; }
	}

	/// <summary>
	/// Gets the right content template.
	/// </summary>
	/// <value>The right content template.</value>
	[PersistenceMode(PersistenceMode.InnerProperty)]
	public Collection<Control> RightContentTemplate
	{
		get { return this.rightItems; }
	}

	/// <summary>
	/// Gets or sets the text to show in the lower part of the group.
	/// </summary>
	/// <value>The text to show in the lower part of the group.</value>
	public string Text { get; set; }

	#endregion Properties

	#region Methods

	/// <summary>
	/// Déclenche l'événement <see cref="E:System.Web.UI.Control.Init"/>.
	/// </summary>
	/// <param name="e">Objet <see cref="T:System.EventArgs"/> qui contient les données d'événement.</param>
	protected override void OnPreRender(EventArgs e)
	{
		base.OnPreRender(e);

		if (this.leftItems != null)
		{
			foreach (Control obj in this.leftItems)
			{
				this.PlaceHolder1.Controls.Add(obj);
			}
		}

		if (this.rightItems != null)
		{
			foreach (Control obj in this.rightItems)
			{
				this.PlaceHolder2.Controls.Add(obj);
			}
		}

		this.ct_cell.Style.Add("text-align", this.GroupAlign.ToString());
		this.Literal1.Text = this.Text;
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
	}

	#endregion Methods
}