﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonGallery.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;
using System.Collections.ObjectModel;
using System.Web.UI;
using System.Web.UI.WebControls;

/// <summary>
/// Ribbon gallery
/// </summary>
public partial class RibbonGallery : RibbonCollectionControl
{
	#region Fields

	/// <summary>
	/// True if the control can expand
	/// </summary>
	private bool canExpand = true;

	/// <summary>
	/// Number of items per line
	/// </summary>
	private int itemsPerLine = 4;

	/// <summary>
	/// Items to be shown in the visible part of the gallery
	/// </summary>
	private int itemsToShow = 3;

	#endregion Fields

	#region Properties

	/// <summary>
	/// Gets or sets a value indicating whether this instance can expand.
	/// </summary>
	/// <value>
	/// 	<c>true</c> if this instance can expand; otherwise, <c>false</c>.
	/// </value>
	public bool CanExpand
	{
		get
		{
			return this.canExpand;
		}

		set
		{
			this.CheckDisposed();
			this.canExpand = value;
		}
	}

	/// <summary>
	/// Gets or sets the items per line.
	/// </summary>
	/// <value>The items per line.</value>
	public int ItemsPerLine
	{
		get
		{
			return this.itemsPerLine;
		}

		set
		{
			this.CheckDisposed();
			this.itemsPerLine = value;
		}
	}

	/// <summary>
	/// Gets or sets the items to show.
	/// </summary>
	/// <value>The items to show.</value>
	public int ItemsToShow
	{
		get
		{
			return this.itemsToShow;
		}

		set
		{
			this.CheckDisposed();
			this.itemsToShow = value;
		}
	}

	#endregion Properties

	#region Methods

	/// <summary>
	/// Déclenche l'événement <see cref="E:System.Web.UI.Control.Init"/>.
	/// </summary>
	/// <param name="e">Objet <see cref="T:System.EventArgs"/> qui contient les données d'événement.</param>
	protected override void OnInit(EventArgs e)
	{
		base.OnInit(e);

		this.div_expand.Visible = this.canExpand;

		if (this.Items != null)
		{
			int counter = 0;
			Panel pnl = new Panel();
			foreach (Control obj in this.Items)
			{
				if ((counter < this.itemsToShow) && (this.PlaceHolder_itemsVisible.Controls.Count < this.itemsToShow))
				{
					this.PlaceHolder_itemsVisible.Controls.Add(obj);
					counter++;

					if (counter == this.itemsToShow)
					{
						counter = 0;
					}
				}
				else
				{
					if (counter == 0)
					{
						pnl = new Panel();
						pnl.Style.Add("clear", "both");
						this.PlaceHolder_menu.Controls.Add(pnl);
					}

					pnl.Controls.Add(obj);
					counter++;
					if (counter == this.itemsPerLine)
					{
						counter = 0;
					}
				}
			}
		}
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
		this.div_expand.Attributes.Add("onclick", "SBRibbon.OpenGallery('" + this.div_item.ClientID + "', '" + this.div_menu.ClientID + "')");
		this.div_menu.Attributes.Add("onmouseover", "SBRibbon.KeepMenu('" + this.div_menu.ClientID + "')");
		this.div_menu.Attributes.Add("onmouseout", "SBRibbon.HideMenu('" + this.div_menu.ClientID + "')");
		this.div_menu.Attributes.Add("MenuOpener", this.div_menu.ClientID);
	}

	#endregion Methods
}