﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonGallerySubItem.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;

/// <summary>
/// Ribbon gallery sub item
/// </summary>
public partial class RibbonGallerySubItem : RibbonControl
{
	#region Fields

	/// <summary>
	/// Javascript function to call on client click event.
	/// </summary>
	private string clientclick;

	#endregion Fields

	#region Events

	/// <summary>
	/// Occurs when [click].
	/// </summary>
	public event EventHandler Click;

	#endregion Events

	#region Properties

	/// <summary>
	/// Gets or sets the image URL.
	/// </summary>
	/// <value>The image URL.</value>
	public string ImageUrl
	{
		get
		{
			return this.Image1.ImageUrl;
		}

		set
		{
			this.CheckDisposed();
			this.Image1.ImageUrl = value;
		}
	}

	/// <summary>
	/// Gets or sets the the Javascript code to run when item is clicked.
	/// </summary>
	/// <value>The client click.</value>
	public string ClientClick
	{
		get
		{
			return this.clientclick;
		}

		set
		{
			this.CheckDisposed();
			this.clientclick = value;
			this.div_item.Attributes.Add("onclick", value + "; return false;");
		}
	}

	/// <summary>
	/// Gets or sets the text.
	/// </summary>
	/// <value>The text of the item.</value>
	public string Text
	{
		get
		{
			return this.lb_text.Text;
		}

		set
		{
			this.CheckDisposed();
			this.lb_text.Text = value;
		}
	}

	/// <summary>
	/// Gets or sets the tooltip.
	/// </summary>
	/// <value>The tooltip.</value>
	public string Tooltip
	{
		get
		{
			return this.div_item.Attributes["title"];
		}

		set
		{
			this.CheckDisposed();
			this.div_item.Attributes["title"] = value;
		}
	}

	#endregion Properties

	#region Methods
	/*
	/// <summary>
	/// External method to set item's image
	/// </summary>
	/// <param name="url">The URL of the image.</param>
	public void setImage(string url)
	{
		this.ImageUrl = url;
	}

	/// <summary>
	/// External method to set item's text
	/// </summary>
	/// <param name="text">The text to be set.</param>
	public void setText(string text)
	{
		this.Text = text;
	}
	*/

	/// <summary>
	/// Handles the Click event of the LinkButton1 control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void LinkButton1_Click(object sender, EventArgs e)
	{
		this.CheckDisposed();
		EventHandler handler = this.Click;
		if (handler != null)
		{
			handler(this, e);
		}
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
	}

	#endregion Methods
}