﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonGroup.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;
using System.Collections.ObjectModel;
using System.Web.UI;

/// <summary>
/// Enumeration of alignement values
/// </summary>
public enum GrpAlign
{
	/// <summary>
	/// Items would be aligned on left
	/// </summary>
	Left,

	/// <summary>
	/// Items would be aligned on center
	/// </summary>
	Center,

	/// <summary>
	/// Items would be aligned on right
	/// </summary>
	Right
}

/// <summary>
/// Ribbon group
/// </summary>
public partial class RibbonGroup : RibbonCollectionControl
{
	#region Ctor

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonGroup"/> class.
	/// </summary>
	public RibbonGroup()
	{
	}
	#endregion Ctor

	#region Properties

	/// <summary>
	/// Gets or sets the items alignment in the group
	/// </summary>
	public GrpAlign GroupAlign { get; set; }

	/// <summary>
	/// Gets or sets the text to show in the lower part of the group.
	/// </summary>
	/// <value>The new text value.</value>
	public string Text { get; set; }

	#endregion Properties

	#region Methods

	/// <summary>
	/// Déclenche l'événement <see cref="E:System.Web.UI.Control.Init"/>.
	/// </summary>
	/// <param name="e">Objet <see cref="T:System.EventArgs"/> qui contient les données d'événement.</param>
	protected override void OnPreRender(EventArgs e)
	{
		base.OnPreRender(e);

		if (this.Items != null)
		{
			foreach (Control obj in this.Items)
			{
				this.PlaceHolder1.Controls.Add(obj);
			}
		}

		this.Literal1.Text = this.Text;
		this.tt_cell.Attributes["title"] = this.Text;
		this.ct_cell.Style.Add("text-align", this.GroupAlign.ToString());
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
	}

	#endregion Methods
}