﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonItemBase.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>François Le Rolland</author>
//-----------------------------------------------------------------------------
using System;

/// <summary>
/// Parent control for all RibbonXXXItem classes.
/// </summary>
public partial class RibbonItemBase : RibbonControl
{
	#region Fields

	/// <summary>
	/// Javascript function to call on client click event.
	/// </summary>
	private string clientclick;

	#endregion Fields

	#region Ctor

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonItemBase"/> class.
	/// </summary>
	public RibbonItemBase()
	{
	}
	#endregion Ctor

	#region Events

	/// <summary>
	/// Occurs when [click].
	/// </summary>
	public event EventHandler Click;

	#endregion Events

	#region Properties

	/// <summary>
	/// Gets or sets the image URL.
	/// </summary>
	/// <value>The image URL.</value>
	public string ImageUrl
	{
		get;
		set;
	}

	/// <summary>
	/// Gets or sets the on client click.
	/// </summary>
	/// <value>The on client click.</value>
	public string OnClientClick
	{
		get
		{
			return this.clientclick;
		}

		set
		{
			this.CheckDisposed();
			this.clientclick = value;
			this.div_item.Attributes.Add("onclick", value + "; return false;");
		}
	}

	/// <summary>
	/// Gets or sets the tooltip.
	/// </summary>
	/// <value>The tooltip.</value>
	public string Tooltip
	{
		get;
		set;
	}

	#endregion Properties

	#region Methods

	/// <summary>
	/// Handles the Click event of the LinkButton1 control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void LinkButton1_Click(object sender, EventArgs e)
	{
		this.CheckDisposed();
		EventHandler handler = this.Click;
		if (handler != null)
		{
			handler(this, e);
		}
	}

	/// <summary>
	/// Raises the <see cref="E:System.Web.UI.Control.PreRender"/> event.
	/// </summary>
	/// <param name="e">An <see cref="T:System.EventArgs"/> object that contains the event data.</param>
	protected override void OnPreRender(EventArgs e)
	{
		this.div_item.Attributes["title"] = this.Tooltip;
		this.Image1.ImageUrl = this.ImageUrl;
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
	}

	#endregion Methods
}
