﻿//-----------------------------------------------------------------------------
// <copyright file="RibbonMultiLineGroup.ascx.cs" company="Ortems">
//	 Copyright (c) Sébastien Bouez. All rights reserved.
// </copyright>
// <author>Sébastien Bouez</author>
//-----------------------------------------------------------------------------
using System;
using System.Collections.ObjectModel;
using System.Web.UI;

/// <summary>
/// Ribbon multiline group
/// </summary>
public partial class RibbonMultiLineGroup : RibbonControl
{
	#region Fields

	/// <summary>
	/// Bottom items of the group
	/// </summary>
	private Collection<Control> bottomItems;

	/// <summary>
	/// Middle items of the group
	/// </summary>
	private Collection<Control> middleItems;

	/// <summary>
	/// Top items of the group
	/// </summary>
	private Collection<Control> topItems;

	#endregion Fields

	/// <summary>
	/// Initializes a new instance of the <see cref="RibbonMultiLineGroup"/> class.
	/// </summary>
	public RibbonMultiLineGroup()
	{
		this.bottomItems = new Collection<Control>();
		this.middleItems = new Collection<Control>();
		this.topItems = new Collection<Control>();
	}

	#region Properties

	/// <summary>
	/// Gets the bottom content template.
	/// </summary>
	/// <value>The bottom content template.</value>
	[PersistenceMode(PersistenceMode.InnerProperty)]
	public Collection<Control> BottomContentTemplate
	{
		get { return this.bottomItems; }
	}

	/// <summary>
	/// Gets the middle content template.
	/// </summary>
	/// <value>The middle content template.</value>
	[PersistenceMode(PersistenceMode.InnerProperty)]
	public Collection<Control> MiddleContentTemplate
	{
		get { return this.middleItems; }
	}

	/// <summary>
	/// Gets or sets the text.
	/// </summary>
	/// <value>The text of the control.</value>
	public string Text
	{
		get
		{
			return this.Literal1.Text;
		}

		set
		{
			this.CheckDisposed();
			this.Literal1.Text = value;
			this.tt_cell.Attributes["title"] = value;
		}
	}

	/// <summary>
	/// Gets the top content template.
	/// </summary>
	/// <value>The top content template.</value>
	[PersistenceMode(PersistenceMode.InnerProperty)]
	public Collection<Control> TopContentTemplate
	{
		get { return this.topItems; }
	}

	#endregion Properties

	#region Methods

	/// <summary>
	/// Déclenche l'événement <see cref="E:System.Web.UI.Control.Init"/>.
	/// </summary>
	/// <param name="e">Objet <see cref="T:System.EventArgs"/> qui contient les données d'événement.</param>
	protected override void OnInit(EventArgs e)
	{
		base.OnInit(e);

		if (this.topItems != null)
		{
			foreach (Control obj in this.topItems)
			{
				this.PlaceHolder_top.Controls.Add(obj);
			}
		}

		if (this.middleItems != null)
		{
			foreach (Control obj in this.middleItems)
			{
				this.PlaceHolder_middle.Controls.Add(obj);
			}
		}

		if (this.bottomItems != null)
		{
			foreach (Control obj in this.bottomItems)
			{
				this.PlaceHolder_bottom.Controls.Add(obj);
			}
		}
	}

	/// <summary>
	/// Handles the Load event of the Page control.
	/// </summary>
	/// <param name="sender">The source of the event.</param>
	/// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
	protected void Page_Load(object sender, EventArgs e)
	{
	}

	#endregion Methods
}